@@ -33,6 +33,12 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+/**
+ * SECTION:common
+ * @title: Common
+ * @short_description: Muffin common types
+ */
+
 typedef struct _MetaResizePopup MetaResizePopup;
 
 typedef enum
@@ -56,10 +62,8 @@ typedef enum
   META_FRAME_ABOVE                    = 1 << 16,
   META_FRAME_TILED_LEFT               = 1 << 17,
   META_FRAME_TILED_RIGHT              = 1 << 18,
-  META_FRAME_ALLOWS_VERTICAL_RESIZE   = (META_FRAME_ALLOWS_TOP_RESIZE |
-                                         META_FRAME_ALLOWS_BOTTOM_RESIZE),
-  META_FRAME_ALLOWS_HORIZONTAL_RESIZE = (META_FRAME_ALLOWS_LEFT_RESIZE |
-                                         META_FRAME_ALLOWS_RIGHT_RESIZE)
+  META_FRAME_ALLOWS_VERTICAL_RESIZE   = (META_FRAME_ALLOWS_TOP_RESIZE | META_FRAME_ALLOWS_BOTTOM_RESIZE),
+  META_FRAME_ALLOWS_HORIZONTAL_RESIZE = (META_FRAME_ALLOWS_LEFT_RESIZE | META_FRAME_ALLOWS_RIGHT_RESIZE)
 } MetaFrameFlags;
 
 typedef enum
@@ -82,7 +86,8 @@ typedef enum
   META_MENU_OP_MOVE_RIGHT  = 1 << 14,
   META_MENU_OP_MOVE_UP     = 1 << 15,
   META_MENU_OP_MOVE_DOWN   = 1 << 16,
-  META_MENU_OP_RECOVER     = 1 << 17
+  META_MENU_OP_RECOVER     = 1 << 17,
+  META_MENU_OP_MOVE_NEW    = 1 << 18
 } MetaMenuOp;
 
 typedef struct _MetaWindowMenu MetaWindowMenu;
@@ -237,7 +242,8 @@ typedef enum
   META_MOTION_UP_LEFT = -5,
   META_MOTION_UP_RIGHT = -6,
   META_MOTION_DOWN_LEFT = -7,
-  META_MOTION_DOWN_RIGHT = -8
+  META_MOTION_DOWN_RIGHT = -8,
+  META_MOTION_NOT_EXIST_YET = -30
 } MetaMotionDirection;
 
 /* Sometimes we want to talk about sides instead of directions; note
@@ -272,12 +278,32 @@ typedef enum
   META_BUTTON_FUNCTION_LAST
 } MetaButtonFunction;
 
+typedef enum {
+  META_TILE_NONE,
+  META_TILE_LEFT,
+  META_TILE_RIGHT,
+  META_TILE_ULC,
+  META_TILE_LLC,
+  META_TILE_URC,
+  META_TILE_LRC,
+  META_TILE_TOP,
+  META_TILE_BOTTOM,
+  META_TILE_MAXIMIZE
+} MetaTileMode;
+
 typedef enum {
     META_WINDOW_TILE_TYPE_NONE,
     META_WINDOW_TILE_TYPE_TILED,
     META_WINDOW_TILE_TYPE_SNAPPED
 } MetaWindowTileType;
 
+typedef enum {
+    META_BELL_TYPE_NONE,
+    META_BELL_TYPE_STICKY_KEYS,
+    META_BELL_TYPE_SLOW_KEYS,
+    META_BELL_TYPE_BOUNCE_KEYS
+} MetaBellType;
+
 #define MAX_BUTTONS_PER_CORNER META_BUTTON_FUNCTION_LAST
 
 typedef struct _MetaButtonLayout MetaButtonLayout;
@@ -400,8 +426,18 @@ typedef enum
 {
   META_PLACEMENT_MODE_AUTOMATIC,
   META_PLACEMENT_MODE_POINTER,
-  META_PLACEMENT_MODE_MANUAL
+  META_PLACEMENT_MODE_MANUAL,
+  META_PLACEMENT_MODE_CENTER
 } MetaPlacementMode;
 
+/*
+ * Background transition
+ */
+typedef enum
+{
+  META_BACKGROUND_TRANSITION_NONE,
+  META_BACKGROUND_TRANSITION_FADEIN,
+  META_BACKGROUND_TRANSITION_BLEND
+} MetaBackgroundTransition;
 
 #endif
