@@ -60,14 +60,13 @@ typedef enum
   META_PREF_VISUAL_BELL,
   META_PREF_AUDIBLE_BELL,
   META_PREF_VISUAL_BELL_TYPE,
-  META_PREF_GNOME_ACCESSIBILITY,
   META_PREF_GNOME_ANIMATIONS,
   META_PREF_CURSOR_THEME,
   META_PREF_CURSOR_SIZE,
   META_PREF_RESIZE_WITH_RIGHT_BUTTON,
   META_PREF_EDGE_TILING,
   META_PREF_FORCE_FULLSCREEN,
-  META_PREF_LIVE_HIDDEN_WINDOWS,
+  META_PREF_EDGE_RESISTANCE_WINDOW,
   META_PREF_WORKSPACES_ONLY_ON_PRIMARY,
   META_PREF_DRAGGABLE_BORDER_WIDTH,
   META_PREF_TILE_HUD_THRESHOLD,
@@ -77,6 +76,7 @@ typedef enum
   META_PREF_INVERT_WORKSPACE_FLIP_DIRECTION,
   META_PREF_TILE_MAXIMIZE,
   META_PREF_PLACEMENT_MODE,
+  META_PREF_BACKGROUND_TRANSITION,
   META_PREF_MIN_WIN_OPACITY,
   META_PREF_MOUSE_ZOOM_ENABLED,
   META_PREF_MOUSE_BUTTON_ZOOM_MODS
@@ -120,6 +120,7 @@ int                         meta_prefs_get_auto_raise_delay   (void);
 gboolean                    meta_prefs_get_gnome_accessibility (void);
 gboolean                    meta_prefs_get_gnome_animations   (void);
 gboolean                    meta_prefs_get_edge_tiling        (void);
+gboolean                    meta_prefs_get_edge_resistance_window (void);
 
 const char*                 meta_prefs_get_screenshot_command (void);
 
@@ -155,9 +156,6 @@ void meta_prefs_set_compositing_manager (gboolean whether);
 
 void meta_prefs_set_force_fullscreen (gboolean whether);
 
-gboolean meta_prefs_get_live_hidden_windows (void);
-void     meta_prefs_set_live_hidden_windows (gboolean whether);
-
 gboolean meta_prefs_get_workspaces_only_on_primary (void);
 
 int      meta_prefs_get_draggable_border_width (void);
@@ -351,4 +349,6 @@ CDesktopVisualBellType meta_prefs_get_visual_bell_type (void);
 
 MetaPlacementMode meta_prefs_get_placement_mode (void);
 
+MetaBackgroundTransition meta_prefs_get_background_transition (void);
+
 #endif
